
Charsets
-------

**Example:**



    <?php

	//Add the following line of code inside the application header:
	//<meta http-equiv="Content-Type" content="text/html; charset=utf-8">

	//or:
	header('Content-Type: text/html; charset=utf-8');

	?>


	